@@ -1,8 +1,9 @@
 
 /* Generated data (by glib-mkenums) */
 
-#include <pango.h>
+#include "config.h"
 
+#include <pango.h>
 /* enumerations from "pango-attributes.h" */
 GType
 pango_attr_type_get_type (void)
@@ -36,6 +37,8 @@ pango_attr_type_get_type (void)
         { PANGO_ATTR_GRAVITY, "PANGO_ATTR_GRAVITY", "gravity" },
         { PANGO_ATTR_GRAVITY_HINT, "PANGO_ATTR_GRAVITY_HINT", "gravity-hint" },
         { PANGO_ATTR_FONT_FEATURES, "PANGO_ATTR_FONT_FEATURES", "font-features" },
+        { PANGO_ATTR_FOREGROUND_ALPHA, "PANGO_ATTR_FOREGROUND_ALPHA", "foreground-alpha" },
+        { PANGO_ATTR_BACKGROUND_ALPHA, "PANGO_ATTR_BACKGROUND_ALPHA", "background-alpha" },
         { 0, NULL, NULL }
       };
       GType g_define_type_id =
@@ -45,7 +48,6 @@ pango_attr_type_get_type (void)
 
   return g_define_type_id__volatile;
 }
-
 GType
 pango_underline_get_type (void)
 {
@@ -68,7 +70,6 @@ pango_underline_get_type (void)
 
   return g_define_type_id__volatile;
 }
-
 /* enumerations from "pango-bidi-type.h" */
 GType
 pango_bidi_type_get_type (void)
@@ -106,7 +107,6 @@ pango_bidi_type_get_type (void)
 
   return g_define_type_id__volatile;
 }
-
 GType
 pango_direction_get_type (void)
 {
@@ -131,7 +131,6 @@ pango_direction_get_type (void)
 
   return g_define_type_id__volatile;
 }
-
 /* enumerations from "pango-coverage.h" */
 GType
 pango_coverage_level_get_type (void)
@@ -154,7 +153,6 @@ pango_coverage_level_get_type (void)
 
   return g_define_type_id__volatile;
 }
-
 /* enumerations from "pango-font.h" */
 GType
 pango_style_get_type (void)
@@ -176,7 +174,6 @@ pango_style_get_type (void)
 
   return g_define_type_id__volatile;
 }
-
 GType
 pango_variant_get_type (void)
 {
@@ -196,7 +193,6 @@ pango_variant_get_type (void)
 
   return g_define_type_id__volatile;
 }
-
 GType
 pango_weight_get_type (void)
 {
@@ -226,7 +222,6 @@ pango_weight_get_type (void)
 
   return g_define_type_id__volatile;
 }
-
 GType
 pango_stretch_get_type (void)
 {
@@ -253,7 +248,6 @@ pango_stretch_get_type (void)
 
   return g_define_type_id__volatile;
 }
-
 GType
 pango_font_mask_get_type (void)
 {
@@ -269,6 +263,7 @@ pango_font_mask_get_type (void)
         { PANGO_FONT_MASK_STRETCH, "PANGO_FONT_MASK_STRETCH", "stretch" },
         { PANGO_FONT_MASK_SIZE, "PANGO_FONT_MASK_SIZE", "size" },
         { PANGO_FONT_MASK_GRAVITY, "PANGO_FONT_MASK_GRAVITY", "gravity" },
+        { PANGO_FONT_MASK_VARIATIONS, "PANGO_FONT_MASK_VARIATIONS", "variations" },
         { 0, NULL, NULL }
       };
       GType g_define_type_id =
@@ -278,7 +273,6 @@ pango_font_mask_get_type (void)
 
   return g_define_type_id__volatile;
 }
-
 /* enumerations from "pango-gravity.h" */
 GType
 pango_gravity_get_type (void)
@@ -302,7 +296,6 @@ pango_gravity_get_type (void)
 
   return g_define_type_id__volatile;
 }
-
 GType
 pango_gravity_hint_get_type (void)
 {
@@ -323,7 +316,6 @@ pango_gravity_hint_get_type (void)
 
   return g_define_type_id__volatile;
 }
-
 /* enumerations from "pango-layout.h" */
 GType
 pango_alignment_get_type (void)
@@ -345,7 +337,6 @@ pango_alignment_get_type (void)
 
   return g_define_type_id__volatile;
 }
-
 GType
 pango_wrap_mode_get_type (void)
 {
@@ -366,7 +357,6 @@ pango_wrap_mode_get_type (void)
 
   return g_define_type_id__volatile;
 }
-
 GType
 pango_ellipsize_mode_get_type (void)
 {
@@ -388,7 +378,6 @@ pango_ellipsize_mode_get_type (void)
 
   return g_define_type_id__volatile;
 }
-
 /* enumerations from "pango-renderer.h" */
 GType
 pango_render_part_get_type (void)
@@ -411,7 +400,6 @@ pango_render_part_get_type (void)
 
   return g_define_type_id__volatile;
 }
-
 /* enumerations from "pango-script.h" */
 GType
 pango_script_get_type (void)
@@ -510,6 +498,35 @@ pango_script_get_type (void)
         { PANGO_SCRIPT_SHARADA, "PANGO_SCRIPT_SHARADA", "sharada" },
         { PANGO_SCRIPT_SORA_SOMPENG, "PANGO_SCRIPT_SORA_SOMPENG", "sora-sompeng" },
         { PANGO_SCRIPT_TAKRI, "PANGO_SCRIPT_TAKRI", "takri" },
+        { PANGO_SCRIPT_BASSA_VAH, "PANGO_SCRIPT_BASSA_VAH", "bassa-vah" },
+        { PANGO_SCRIPT_CAUCASIAN_ALBANIAN, "PANGO_SCRIPT_CAUCASIAN_ALBANIAN", "caucasian-albanian" },
+        { PANGO_SCRIPT_DUPLOYAN, "PANGO_SCRIPT_DUPLOYAN", "duployan" },
+        { PANGO_SCRIPT_ELBASAN, "PANGO_SCRIPT_ELBASAN", "elbasan" },
+        { PANGO_SCRIPT_GRANTHA, "PANGO_SCRIPT_GRANTHA", "grantha" },
+        { PANGO_SCRIPT_KHOJKI, "PANGO_SCRIPT_KHOJKI", "khojki" },
+        { PANGO_SCRIPT_KHUDAWADI, "PANGO_SCRIPT_KHUDAWADI", "khudawadi" },
+        { PANGO_SCRIPT_LINEAR_A, "PANGO_SCRIPT_LINEAR_A", "linear-a" },
+        { PANGO_SCRIPT_MAHAJANI, "PANGO_SCRIPT_MAHAJANI", "mahajani" },
+        { PANGO_SCRIPT_MANICHAEAN, "PANGO_SCRIPT_MANICHAEAN", "manichaean" },
+        { PANGO_SCRIPT_MENDE_KIKAKUI, "PANGO_SCRIPT_MENDE_KIKAKUI", "mende-kikakui" },
+        { PANGO_SCRIPT_MODI, "PANGO_SCRIPT_MODI", "modi" },
+        { PANGO_SCRIPT_MRO, "PANGO_SCRIPT_MRO", "mro" },
+        { PANGO_SCRIPT_NABATAEAN, "PANGO_SCRIPT_NABATAEAN", "nabataean" },
+        { PANGO_SCRIPT_OLD_NORTH_ARABIAN, "PANGO_SCRIPT_OLD_NORTH_ARABIAN", "old-north-arabian" },
+        { PANGO_SCRIPT_OLD_PERMIC, "PANGO_SCRIPT_OLD_PERMIC", "old-permic" },
+        { PANGO_SCRIPT_PAHAWH_HMONG, "PANGO_SCRIPT_PAHAWH_HMONG", "pahawh-hmong" },
+        { PANGO_SCRIPT_PALMYRENE, "PANGO_SCRIPT_PALMYRENE", "palmyrene" },
+        { PANGO_SCRIPT_PAU_CIN_HAU, "PANGO_SCRIPT_PAU_CIN_HAU", "pau-cin-hau" },
+        { PANGO_SCRIPT_PSALTER_PAHLAVI, "PANGO_SCRIPT_PSALTER_PAHLAVI", "psalter-pahlavi" },
+        { PANGO_SCRIPT_SIDDHAM, "PANGO_SCRIPT_SIDDHAM", "siddham" },
+        { PANGO_SCRIPT_TIRHUTA, "PANGO_SCRIPT_TIRHUTA", "tirhuta" },
+        { PANGO_SCRIPT_WARANG_CITI, "PANGO_SCRIPT_WARANG_CITI", "warang-citi" },
+        { PANGO_SCRIPT_AHOM, "PANGO_SCRIPT_AHOM", "ahom" },
+        { PANGO_SCRIPT_ANATOLIAN_HIEROGLYPHS, "PANGO_SCRIPT_ANATOLIAN_HIEROGLYPHS", "anatolian-hieroglyphs" },
+        { PANGO_SCRIPT_HATRAN, "PANGO_SCRIPT_HATRAN", "hatran" },
+        { PANGO_SCRIPT_MULTANI, "PANGO_SCRIPT_MULTANI", "multani" },
+        { PANGO_SCRIPT_OLD_HUNGARIAN, "PANGO_SCRIPT_OLD_HUNGARIAN", "old-hungarian" },
+        { PANGO_SCRIPT_SIGNWRITING, "PANGO_SCRIPT_SIGNWRITING", "signwriting" },
         { 0, NULL, NULL }
       };
       GType g_define_type_id =
@@ -519,7 +536,6 @@ pango_script_get_type (void)
 
   return g_define_type_id__volatile;
 }
-
 /* enumerations from "pango-tabs.h" */
 GType
 pango_tab_align_get_type (void)
@@ -540,6 +556,5 @@ pango_tab_align_get_type (void)
   return g_define_type_id__volatile;
 }
 
-
 /* Generated data ends here */
 
